@@ -2,7 +2,7 @@
 
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -107,7 +107,8 @@ typedef enum
 	FOLDER_TREE_CHANGED 		= 1 << 2,
 	FOLDER_ADD_FOLDERITEM 		= 1 << 3,
 	FOLDER_REMOVE_FOLDERITEM 	= 1 << 4,
-	FOLDER_RENAME_FOLDERITEM	= 1 << 5
+	FOLDER_RENAME_FOLDERITEM	= 1 << 5,
+	FOLDER_MOVE_FOLDERITEM		= 1 << 6
 } FolderUpdateFlags;
 
 typedef enum
@@ -129,12 +130,12 @@ typedef void (*FolderItemFunc)	(FolderItem	*item,
 					 gpointer	 data);
 
 
-#include "folder_item_prefs.h"
-
-#include "procmsg.h"
-#include "msgcache.h"
+#include "proctypes.h"
 #include "xml.h"
 #include "prefs_account.h"
+#include "matchertypes.h"
+
+struct _MsgCache;
 
 struct _Folder
 {
@@ -160,6 +161,23 @@ struct _Folder
 	GHashTable *newsart;
 };
 
+/**
+ * Callback used to convey progress information of a specific search.
+ *
+ * \param data User-provided data
+ * \param on_server Whether or not the current progress information originated from the
+ *                  server
+ * \param at Number of the last message processed
+ * \param matched Number of messages with definitive matches found so far
+ * \param total Number of messages to be processed
+ *
+ * \note
+ * Even if the mailserver does not support progress reports, an instance of this type
+ * should be invoked when serverside search starts and ends, with \c at set to \c 0 and
+ * \c total, respectively.
+ */
+typedef gboolean (*SearchProgressNotify)(gpointer data, gboolean on_server, guint at, guint matched, guint total);
+
 struct _FolderClass
 {
 	/**
@@ -176,7 +194,19 @@ struct _FolderClass
 	 * user. Can be upper and lowercase unlike the idstr.
 	 */
 	gchar	   *uistr;
+	/**
+	* A boolean to indicate whether or not the FolderClass supports search on the
+	* server. If \c TRUE, setting \c on_server in \c search_msgs offloads search to
+	* the server.
+	*/
+	gboolean    supports_server_search;
+
+	/**
+	 * Klass-specific prefs pages
+	 */
 	
+	GSList *prefs_pages;
+
 	/* virtual functions */
 
 	/* Folder funtions */
@@ -294,7 +324,7 @@ struct _FolderClass
 	XMLTag		*(*item_get_xml)	(Folder		*folder,
 						 FolderItem	*item);
 	/**
-	 * Get a local path for the \c FolderItem where Sylpheed can save
+	 * Get a local path for the \c FolderItem where Claws Mail can save
 	 * it's cache data. For local directory based folders this can be the
 	 * real path. For other folders it can be the local cache directory.
 	 *
@@ -342,12 +372,9 @@ struct _FolderClass
 	 * Close a \c FolderItem. Called when the user deselects a
 	 * \c FolderItem.
 	 * 
-	 * \attention In Sylpheed-Main operations can only be done on the
-	 *            \c FolderItem that is opened in the SummaryView. This
-	 *            \c FolderItem will be closed when you select a new
-	 *            \c FolderItem in the FolderView. In Claws operations can
-	 *            be done any time on any folder and you should not expect
-	 *            that all \c FolderItems get closed after operations
+	 * \attention In Claws Mail, operations can be done any time on any
+	 *            folder and you should not expect that all
+	 *            \c FolderItems get closed after operations
 	 *
 	 * \param folder The \c Folder that contains the \c FolderItem
 	 * \param item The \c FolderItem that should be closed
@@ -474,7 +501,7 @@ struct _FolderClass
 	gint     	(*add_msgs)             (Folder         *folder,
                                     		 FolderItem     *dest,
                                     		 GSList         *file_list,
-                                    		 GRelation	*relation);
+                                    		 GHashTable	*relation);
 	/**
 	 * Copy a message to a FolderItem
 	 *
@@ -505,7 +532,59 @@ struct _FolderClass
 	gint    	(*copy_msgs)		(Folder		*folder,
 						 FolderItem	*dest,
 						 MsgInfoList	*msglist,
-                                    		 GRelation	*relation);
+                                    		 GHashTable	*relation);
+
+	/**
+	 * Search the given FolderItem for messages matching \c predicate.
+	 * The search may be offloaded to the server if the \c folder
+	 * supports server side search, as indicated by \c supports_server_search.
+	 *
+	 * \param folder The \c Folder of the container FolderItem
+	 * \param container The \c FolderItem containing the messages to be searched
+	 * \param msgs The \c MsgNumberList results will be saved to.
+	 *             If <tt>*msgs != NULL</tt>, the search will be restricted to
+	 *             messages whose numbers are contained therein.
+	 *             If \c on_server is considered \c FALSE, messages are guaranteed to
+	 *             be processed in the order they are listed in \c msgs.
+	 *             On error, \c msgs will not be changed.
+	 * \param on_server Whether or not the search should be offloaded to the server.
+	 *                  If \c on_server is not \c NULL and points to a \c TRUE value,
+	 *                  search will be done on the server. If \c predicate contains
+	 *                  one or more atoms the server does not support, the value
+	 *                  pointed to by \c on_server will be set to \c FALSE upon return.
+	 *                  In this case, \c msgs must still contain a valid superset of
+	 *                  messages actually matched by \c predicate, or this method must
+	 *                  return an error.
+	 *                  \c on_server may only point to a \c TRUE value if
+	 *                  \c supports_server_search is also \c TRUE.
+	 *                  \c NULL and pointer to \c FALSE are considered equivalent and
+	 *                  will start a client-only search.
+	 * \param predicate The \c MatcherList to use in the search
+	 * \param progress_cb Called for every message searched.
+	 *                    When search is offloaded to the server, this function
+	 *                    may or may not be called, depending on the implementation.
+	 *                    The second argument of this function will be the number of
+	 *                    messages already processed.
+	 *                    Return \c FALSE from this function to end the search.
+	 *                    May be \c NULL, no calls will be made in this case.
+	 * \param progress_data First argument value for \c progress_cb
+	 * \return Number of messages that matched \c predicate on success, a negative
+	 *         number otherwise.
+	 *
+	 * \note
+	 * When search is stopped by returning \c FALSE from \c progress_cb, \c msgs will
+	 * contain all messages found until the point of cancellation. The number of
+	 * messages found will be returned as indicated above.
+	 */
+	gint		(*search_msgs)		(Folder			*folder,
+						 FolderItem		*container,
+						 MsgNumberList		**msgs,
+						 gboolean		*on_server,
+						 MatcherList		*predicate,
+						 SearchProgressNotify	progress_cb,
+						 gpointer		progress_data);
+
+
 	/**
 	 * Remove a message from a \c FolderItem.
 	 *
@@ -520,7 +599,7 @@ struct _FolderClass
 	gint    	(*remove_msgs)		(Folder		*folder,
 						 FolderItem	*item,
 						 MsgInfoList    *msglist,
-						 GRelation	*relation);
+						 GHashTable	*relation);
 	gint    	(*expunge)		(Folder		*folder,
 						 FolderItem	*item);
 	/**
@@ -578,7 +657,7 @@ struct _FolderClass
 	gint		(*get_flags)		(Folder		*folder,
 						 FolderItem	*item,
 						 MsgInfoList	*msglist,
-						 GRelation	*msgflags);
+						 GHashTable	*msgflags);
 	
 	/* Sets batch mode for a FolderItem. It means that numerous flags updates
 	 * could follow, and the FolderClass implementation can cache them in order
@@ -633,6 +712,8 @@ enum {
 	ITEM_SCANNING
 };
 
+struct _FolderItemPrefs;
+
 struct _FolderItem
 {
 	SpecialFolderItemType stype;
@@ -657,7 +738,7 @@ struct _FolderItem
 
 	gint last_num;
 
-	MsgCache *cache;
+	struct _MsgCache *cache;
 	gboolean cache_dirty;
 	gboolean mark_dirty;
 	gboolean tags_dirty;
@@ -672,6 +753,7 @@ struct _FolderItem
 	guint ret_rcpt       : 1; /* return receipt       */
 	guint search_match   : 1;
 	guint hide_del_msgs : 1; /* hide deleted messages   */
+	guint hide_read_threads : 1; /* hide threads with only read messages   */
 
 	gint op_count;
 	guint opened         : 1; /* opened by summary view */
@@ -692,7 +774,7 @@ struct _FolderItem
 
 	gpointer data;
 
-	FolderItemPrefs * prefs;
+	struct _FolderItemPrefs * prefs;
 	
 	/* for faster search of special parents */
 	SpecialFolderItemType parent_stype;
@@ -711,6 +793,7 @@ struct _PersistPrefs
 	guint		hide_read_msgs	: 1; /* CLAWS */
 	guint		ret_rcpt	: 1; /* CLAWS */
 	guint		hide_del_msgs	: 1; /* CLAWS */
+	guint		hide_read_threads	: 1;
 };
 
 struct _FolderUpdateData
@@ -718,6 +801,7 @@ struct _FolderUpdateData
 	Folder			*folder;
 	FolderUpdateFlags	 update_flags;
 	FolderItem		*item;
+	FolderItem		*item2;
 };
 
 struct _FolderItemUpdateData
@@ -774,7 +858,6 @@ GList *folder_get_list		(void);
 gint   folder_read_list		(void);
 void   folder_write_list	(void);
 void   folder_scan_tree		(Folder *folder, gboolean rebuild);
-void   folder_fast_scan_tree	(Folder *folder);
 FolderItem *folder_create_folder(FolderItem	*parent, const gchar *name);
 gint   folder_item_rename	(FolderItem *item, gchar *newname);
 void   folder_update_op_count		(void);
@@ -788,6 +871,7 @@ void folder_count_total_msgs(guint *new_msgs, guint *unread_msgs,
 gchar *folder_get_status	(GPtrArray	*folders,
 				 gboolean	 full);
 
+Folder 	   *folder_find_from_identifier		(const gchar *identifier);
 Folder     *folder_find_from_path		(const gchar	*path);
 Folder     *folder_find_from_name		(const gchar	*name,
 						 FolderClass	*klass);
@@ -814,7 +898,7 @@ FolderItem *folder_get_default_queue	(void);
 FolderItem *folder_get_default_queue_for_class(FolderType type);
 FolderItem *folder_get_default_trash	(void);
 FolderItem *folder_get_default_trash_for_class(FolderType type);
-FolderItem *folder_get_default_processing (void);
+FolderItem *folder_get_default_processing (int account_id);
 void folder_set_missing_folders		(void);
 void folder_unref_account_all		(PrefsAccount	*account);
 
@@ -831,6 +915,8 @@ MsgInfo *folder_item_get_msginfo	(FolderItem 	*item,
 MsgInfo *folder_item_get_msginfo_by_msgid(FolderItem 	*item,
 					 const gchar 	*msgid);
 GSList *folder_item_get_msg_list	(FolderItem 	*item);
+MsgNumberList *folder_item_get_number_list(FolderItem *item);
+
 /* return value is locale charset */
 gchar *folder_item_fetch_msg		(FolderItem	*item,
 					 gint		 num);
@@ -857,6 +943,13 @@ gint   folder_item_copy_msg		(FolderItem	*dest,
 					 MsgInfo	*msginfo);
 gint   folder_item_copy_msgs		(FolderItem	*dest,
 					 GSList		*msglist);
+gint   folder_item_search_msgs		(Folder			*folder,
+					 FolderItem		*container,
+					 MsgNumberList		**msgs,
+					 gboolean		*on_server,
+					 MatcherList		*predicate,
+					 SearchProgressNotify	progress_cb,
+					 gpointer		progress_data);
 gint   folder_item_remove_msg		(FolderItem	*item,
 					 gint		 num);
 gint   folder_item_remove_msgs		(FolderItem	*item,
@@ -883,6 +976,7 @@ void folder_item_update_freeze		(void);
 void folder_item_update_thaw		(void);
 void folder_item_set_batch		(FolderItem *item, gboolean batch);
 gboolean folder_has_parent_of_type	(FolderItem *item, SpecialFolderItemType type);
+gboolean folder_is_child_of		(FolderItem *item, FolderItem *possibleChild);
 void folder_synchronise			(Folder *folder);
 gboolean folder_want_synchronise	(Folder *folder);
 gboolean folder_subscribe		(const gchar *uri);
@@ -897,4 +991,17 @@ void folder_item_synchronise		(FolderItem *item);
 void folder_item_discard_cache		(FolderItem *item);
 void folder_item_commit_tags(FolderItem *item, MsgInfo *msginfo, GSList *tags_set, GSList *tags_unset);
 
+
+
+gint folder_item_search_msgs_local	(Folder			*folder,
+					 FolderItem		*container,
+					 MsgNumberList		**msgs,
+					 gboolean		*on_server,
+					 MatcherList		*predicate,
+					 SearchProgressNotify	progress_cb,
+					 gpointer		progress_data);
+
+gchar *folder_get_list_path	(void);
+gboolean folder_local_name_ok(const gchar *name);
+
 #endif /* __FOLDER_H__ */
