@@ -1,14 +1,12 @@
 static char *TEAM_LIST[] = {
 "Holger Berndt <berndth@users.sf.net>",
+"Jonathan Boeing <jonathan@claws-mail.org>",
 "Tristan Chabredier <wwp@claws-mail.org>",
-"Andrej Kacian <andrej@kacian.sk>",
 "Darko Koruga <darko@users.sf.net>",
-"Charles Lehner <charles@claws-mail.org>",
-"Colin Leroy-Mira <colin@colino.net>",
+"Thorsten Maerz <thorsten@claws-mail.org>",
 "Paul Mangan <paul@claws-mail.org>",
 "Ricardo Mones Lastra <ricardo@mones.org>",
 "Salvatore De Paolis <iwkse@claws-mail.org>",
-"Paweł Pękala <c0rn@o2.pl>",
 "Michael Rasmussen <mir@datanom.net>",
 NULL
 };
@@ -21,8 +19,11 @@ static char *EX_TEAM_LIST[] = {
 "Oliver Haertel",
 "Christoph Hohmann",
 "Alfons Hoogervorst",
+"Andrej Kacian",
 "Werner Koch",
-"Thorsten Maerz",
+"Charles Lehner",
+"Colin Leroy-Mira",
+"Paweł Pękala",
 "Leandro A. F. Pereira",
 "Luke Plant",
 "Martin Schaaf",
@@ -63,12 +64,9 @@ NULL
 static char *DOC_TEAM_LIST[] = {
 "[en] Tristan Chabredier <wwp@claws-mail.org>",
 "     Ricardo Mones Lastra <ricardo@mones.org>",
-"     Colin Leroy <colin@colino.net>",
 "     Paul Mangan <paul@claws-mail.org>",
 "[es] Ricardo Mones Lastra <ricardo@mones.org>",
 "[fr] Tristan Chabredier <wwp@claws-mail.org>",
-"     Colin Leroy <colin@colino.net>",
-"[pl] Paweł Pękala <c0rn@gazeta.pl>",
 NULL
 };
 
@@ -100,7 +98,7 @@ static char *CONTRIBS_LIST[] = {
 "Laurent Bigonville",
 "Jean-Luc Biord",
 "Blatinox",
-"Hanno Boeck",
+"Hanno Böck",
 "Pavlo Bohmat",
 "Ralf Bormann",
 "H. Merijn Brand",
@@ -125,7 +123,9 @@ static char *CONTRIBS_LIST[] = {
 "Kevin Day",
 "Matthieu Dazy",
 "Ben Deering",
+"Jean Delvare",
 "Pierric Descamps",
+"Orivej Desh",
 "Rodrigo Dias Arruda Senra",
 "Frank Dietrich",
 "Tim Dijkstra",
@@ -160,6 +160,7 @@ static char *CONTRIBS_LIST[] = {
 "Oliver Haertel",
 "Anders Hammar",
 "Mitko Haralanov",
+"Alexander Lyons Harkness",
 "Hashimoto",
 "Jacob Head",
 "Federico Heinz",
@@ -194,6 +195,7 @@ static char *CONTRIBS_LIST[] = {
 "kazken3",
 "WAKAI Kazunao",
 "Fabian Keil",
+"Jakub Kiciński",
 "Martin Kluge",
 "IWAMOTO Kouichi",
 "Mikhail Kurinnoi",
@@ -221,6 +223,7 @@ static char *CONTRIBS_LIST[] = {
 "Bram Metsch",
 "Hanno Meyer-Thurow",
 "George Michaelson",
+"Raphael Michel",
 "Florian Mickler",
 "Neill Miller",
 "Suzuki Mio",
@@ -250,11 +253,14 @@ static char *CONTRIBS_LIST[] = {
 "Thomas Orgis",
 "Reza Pakdel",
 "Richard Palo",
+"Alvar Penning",
+"Damian Poddebniak",
 "Marcel Pol",
 "Martin Pool",
 "Quar",
 "Don Quijote",
 "Steve Rader",
+"Steve Randall",
 "Jens Rantil",
 "Ravemax",
 "Eric S. Raymond",
@@ -287,6 +293,7 @@ static char *CONTRIBS_LIST[] = {
 "Dale P. Smith",
 "Avinash Sonawane",
 "Andrea Spadaccini",
+"Manuel Stoeckl",
 "Bogdan Sumanariu",
 "TAKANO",
 "TOGAWA",
@@ -301,6 +308,7 @@ static char *CONTRIBS_LIST[] = {
 "Masahiro Tomita",
 "Tomita",
 "Topia",
+"Ramin Yaghoubzadeh Torky",
 "Anders Troback",
 "Tsutsui",
 "Aleksandar Urošević",
@@ -314,6 +322,7 @@ static char *CONTRIBS_LIST[] = {
 "Jonathan Ware",
 "Watanabe",
 "Rafal Weglarz",
+"Florian Weimer",
 "Martin Wicke",
 "Bob Woodside",
 "YAMAGUCHI",
