@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2016 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2021 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@
 #include "prefs_msg_colors.h"
 #include "prefs_summary_open.h"
 
-#define CLAWS_CONFIG_VERSION 3
+#define CLAWS_CONFIG_VERSION 4
 
 typedef struct _PrefsCommon	PrefsCommon;
 
@@ -240,12 +240,13 @@ struct _PrefsCommon
 	ColorlabelPrefs custom_colorlabel[COLORLABELS];
 
 	/* program colors */
-	gulong color[COL_LAST_COLOR_INDEX];
+	GdkRGBA color[COL_LAST_COLOR_INDEX];
 
 	/* image viewer */
 	gboolean display_img;
 	gboolean resize_img;
 	gboolean inline_img;
+	gboolean fit_img_height;
 
 	gboolean trans_hdr;
 	gint display_folder_unread;
@@ -278,7 +279,6 @@ struct _PrefsCommon
 	gboolean goto_last_folder_on_startup;
 
 	ToolbarStyle toolbar_style;
-	gboolean toolbar_detachable;
 	gboolean show_statusbar;
 	gboolean show_col_headers;
 
@@ -354,6 +354,7 @@ struct _PrefsCommon
 	gboolean display_header_pane;
 	gboolean display_header;
 	gboolean display_xface;
+	gboolean save_xface;
 	gint line_space;
 	gboolean render_html;
 	gboolean invoke_plugin_on_html;
@@ -457,7 +458,7 @@ struct _PrefsCommon
 
 	gint io_timeout_secs;
 
-	gboolean gtk_can_change_accels;
+	gboolean gtk_enable_accels;
 	
 	/* Memory cache*/
 	gint cache_max_mem_usage;
@@ -498,6 +499,10 @@ struct _PrefsCommon
 	gint tagswin_height;
 	gint sslmanwin_width;
 	gint sslmanwin_height;
+	gint uriopenerwin_width;
+	gint uriopenerwin_height;
+	gint foldersortwin_width;
+	gint foldersortwin_height;
 	gint addressbookwin_width;
 	gint addressbookwin_height;
 	gint addressbookeditpersonwin_width;
@@ -532,6 +537,7 @@ struct _PrefsCommon
 	gint news_subscribe_width;
 	gint news_subscribe_height;
 
+    gint imap_scan_tree_recurs_limit;
 	gint warn_dnd;
 	gint broken_are_utf8;
 	gint skip_ssl_cert_check;
